@@ -1,19 +1,19 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="vi" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="vi">
 <context>
     <name>CustomDialog</name>
     <message>
-        <location filename="dialog.cpp" line="15"/>
+        <location filename="../dialog.cpp" line="16"/>
         <source>Live environment detected. Please select the root partition of the
  system you want to modify (only Linux partitions are displayed)</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="dialog.cpp" line="22"/>
+        <location filename="../dialog.cpp" line="22"/>
         <source>OK</source>
         <translation>Đồng ý</translation>
     </message>
     <message>
-        <location filename="dialog.cpp" line="23"/>
+        <location filename="../dialog.cpp" line="23"/>
         <source>Cancel</source>
         <translation>Hủy bỏ</translation>
     </message>
@@ -21,337 +21,492 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="mainwindow.ui" line="32"/>
+        <location filename="../mainwindow.ui" line="33"/>
         <source>Options</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="38"/>
-        <source>Kernel parameters</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="58"/>
-        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="61"/>
-        <source>Menu timeout</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="74"/>
-        <source>Boot to</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="81"/>
+        <location filename="../mainwindow.ui" line="39"/>
         <source>Use simplified menu structure without submenus</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="84"/>
+        <location filename="../mainwindow.ui" line="42"/>
         <source>Use flat menus (no submenus)</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="113"/>
+        <location filename="../mainwindow.ui" line="55"/>
+        <source>Boot to</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="78"/>
+        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="81"/>
+        <source>Menu timeout</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="104"/>
+        <source>Kernel parameters</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="117"/>
         <source>seconds</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="120"/>
+        <location filename="../mainwindow.ui" line="124"/>
         <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="123"/>
+        <location filename="../mainwindow.ui" line="127"/>
         <source>Enable saving last boot choice</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="136"/>
+        <location filename="../mainwindow.ui" line="134"/>
+        <source>Manage UEFI Boot Options</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="150"/>
         <source>Background</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="154"/>
+        <location filename="../mainwindow.ui" line="168"/>
         <source>Image</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="167"/>
-        <location filename="mainwindow.ui" line="269"/>
+        <location filename="../mainwindow.ui" line="181"/>
+        <location filename="../mainwindow.ui" line="283"/>
         <source>Enable theme</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="247"/>
+        <location filename="../mainwindow.ui" line="261"/>
         <source>Splash</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="282"/>
+        <location filename="../mainwindow.ui" line="296"/>
         <source>Preview</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="305"/>
+        <location filename="../mainwindow.ui" line="319"/>
         <source>Messages</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="311"/>
+        <location filename="../mainwindow.ui" line="325"/>
         <source>Very detailed</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="318"/>
+        <location filename="../mainwindow.ui" line="332"/>
         <source>Detailed (default setting)</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="328"/>
+        <location filename="../mainwindow.ui" line="342"/>
         <source>Limited</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="344"/>
+        <location filename="../mainwindow.ui" line="358"/>
         <source>Display log</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="397"/>
+        <location filename="../mainwindow.ui" line="411"/>
         <source>Display help </source>
         <translation>Hiển thị bản trợ giúp</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="400"/>
+        <location filename="../mainwindow.ui" line="414"/>
         <source>Help</source>
         <translation>Trợ giúp</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="407"/>
+        <location filename="../mainwindow.ui" line="421"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="439"/>
+        <location filename="../mainwindow.ui" line="453"/>
         <source>About this application</source>
         <translation>Về ứng dụng này</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="442"/>
+        <location filename="../mainwindow.ui" line="456"/>
         <source>About...</source>
         <translation>Về ứng dụng này...</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="449"/>
+        <location filename="../mainwindow.ui" line="463"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="484"/>
+        <location filename="../mainwindow.ui" line="498"/>
         <source>Quit application</source>
         <translation>Thoát ứng dụng</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="487"/>
-        <location filename="mainwindow.cpp" line="665"/>
+        <location filename="../mainwindow.ui" line="501"/>
+        <location filename="../mainwindow.cpp" line="876"/>
         <source>Close</source>
         <translation>Đóng</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="494"/>
+        <location filename="../mainwindow.ui" line="508"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="535"/>
+        <location filename="../mainwindow.ui" line="549"/>
         <source>Apply</source>
         <translation>Áp dụng</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="66"/>
+        <location filename="../mainwindow.cpp" line="72"/>
         <source>Still running</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="66"/>
+        <location filename="../mainwindow.cpp" line="73"/>
         <source>Process still running. Are you sure you want to quit?</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="163"/>
-        <source>Installing bootsplash, please wait</source>
+        <location filename="../mainwindow.cpp" line="203"/>
+        <source>Set timeout</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="170"/>
-        <source>Updating sources</source>
+        <location filename="../mainwindow.cpp" line="203"/>
+        <source>Timeout in seconds:</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="172"/>
-        <source>Installing</source>
+        <location filename="../mainwindow.cpp" line="207"/>
+        <location filename="../mainwindow.cpp" line="421"/>
+        <location filename="../mainwindow.cpp" line="1073"/>
+        <source>Timeout: %1 seconds</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="176"/>
-        <location filename="mainwindow.cpp" line="318"/>
+        <location filename="../mainwindow.cpp" line="218"/>
+        <location filename="../mainwindow.cpp" line="423"/>
+        <location filename="../mainwindow.cpp" line="1072"/>
+        <location filename="../mainwindow.cpp" line="1088"/>
+        <source>Boot Next: %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="224"/>
+        <source>Removal confirmation</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="225"/>
+        <source>Are you sure you want to delete this boot entry?
+%1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="290"/>
+        <location filename="../mainwindow.cpp" line="293"/>
+        <source>Select EFI file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="291"/>
+        <location filename="../mainwindow.cpp" line="294"/>
+        <source>EFI files (*.efi *.EFI)</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="304"/>
+        <location filename="../mainwindow.cpp" line="315"/>
+        <location filename="../mainwindow.cpp" line="346"/>
+        <location filename="../mainwindow.cpp" line="506"/>
+        <location filename="../mainwindow.cpp" line="581"/>
         <source>Error</source>
         <translation>Lỗi</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="176"/>
+        <location filename="../mainwindow.cpp" line="304"/>
+        <source>Could not find the source mountpoint for %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="308"/>
+        <source>Set name</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="308"/>
+        <source>Enter the name for the UEFI menu item:</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="315"/>
+        <source>Something went wrong, could not add entry.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="333"/>
+        <source>Installing bootsplash, please wait</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="340"/>
+        <source>Updating sources</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="342"/>
+        <source>Installing</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="346"/>
         <source>Could not install the bootsplash.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="274"/>
-        <location filename="mainwindow.cpp" line="324"/>
+        <location filename="../mainwindow.cpp" line="425"/>
+        <source>Boot Current: %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="462"/>
+        <location filename="../mainwindow.cpp" line="512"/>
         <source>Cannot continue</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="274"/>
+        <location filename="../mainwindow.cpp" line="462"/>
         <source>Nothing was selected, cannot change boot options. Exiting...</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="319"/>
+        <location filename="../mainwindow.cpp" line="507"/>
         <source>Could not create a temporary folder</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="324"/>
+        <location filename="../mainwindow.cpp" line="513"/>
         <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="561"/>
-        <location filename="mainwindow.cpp" line="857"/>
+        <location filename="../mainwindow.cpp" line="581"/>
+        <source>Something went wrong, could not save boot order.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="767"/>
+        <location filename="../mainwindow.cpp" line="1179"/>
         <source>Updating configuration, please wait</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="608"/>
+        <location filename="../mainwindow.cpp" line="816"/>
         <source>Updating initramfs...</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="617"/>
-        <location filename="mainwindow.cpp" line="869"/>
+        <location filename="../mainwindow.cpp" line="825"/>
+        <location filename="../mainwindow.cpp" line="1191"/>
         <source>Updating grub...</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="621"/>
+        <location filename="../mainwindow.cpp" line="829"/>
         <source>Done</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="621"/>
+        <location filename="../mainwindow.cpp" line="829"/>
         <source>Changes have been successfully applied.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="634"/>
+        <location filename="../mainwindow.cpp" line="840"/>
         <source>About</source>
         <translation>Về ứng dụng này</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="635"/>
+        <location filename="../mainwindow.cpp" line="842"/>
         <source>Version: </source>
         <translation>Phiên bản:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="636"/>
+        <location filename="../mainwindow.cpp" line="843"/>
         <source>Program for selecting common start-up choices</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="638"/>
+        <location filename="../mainwindow.cpp" line="845"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="639"/>
-        <location filename="mainwindow.cpp" line="649"/>
+        <location filename="../mainwindow.cpp" line="846"/>
+        <location filename="../mainwindow.cpp" line="857"/>
         <source>License</source>
         <translation>Giấy phép</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="640"/>
-        <location filename="mainwindow.cpp" line="654"/>
+        <location filename="../mainwindow.cpp" line="847"/>
+        <location filename="../mainwindow.cpp" line="864"/>
         <source>Changelog</source>
         <translation>Nhật kí thay đổi</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="641"/>
+        <location filename="../mainwindow.cpp" line="848"/>
         <source>Cancel</source>
         <translation>Hủy bỏ</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="684"/>
+        <location filename="../mainwindow.cpp" line="906"/>
         <source>MX Boot Options</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="695"/>
+        <location filename="../mainwindow.cpp" line="918"/>
         <source>Running in a Virtual Machine</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="696"/>
+        <location filename="../mainwindow.cpp" line="919"/>
         <source>You current system is running in a Virtual Machine,
 Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="701"/>
+        <location filename="../mainwindow.cpp" line="924"/>
         <source>Plymouth packages not installed</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="701"/>
+        <location filename="../mainwindow.cpp" line="924"/>
         <source>Plymouth packages are not currently installed.
 OK to go ahead and install them?</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="721"/>
+        <location filename="../mainwindow.cpp" line="945"/>
         <source>Images (*.png *.jpg *.jpeg *.tga)</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="823"/>
+        <location filename="../mainwindow.cpp" line="1047"/>
         <source>Press any key to close</source>
         <translation>Nhấn phím bất kì để đóng</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="825"/>
+        <location filename="../mainwindow.cpp" line="1049"/>
         <source>Log not found</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="825"/>
+        <location filename="../mainwindow.cpp" line="1049"/>
         <source>Could not find log at </source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="838"/>
+        <location filename="../mainwindow.cpp" line="1055"/>
+        <source>Edit UEFI Boot Entries</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1058"/>
+        <source>You can use the Up/Down buttons, or drag &amp; drop items to change boot order.
+- Items are listed in the boot order.
+- Grayed out lines are inactive.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1061"/>
+        <location filename="../mainwindow.cpp" line="1108"/>
+        <source>Set ac&amp;tive</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1062"/>
+        <source>&amp;Add entry</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1063"/>
+        <source>Boot &amp;next</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1064"/>
+        <source>&amp;Close</source>
+        <translation>&amp;Đóng</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1065"/>
+        <source>Move &amp;down</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1066"/>
+        <source>&amp;Remove entry</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1067"/>
+        <source>Re&amp;set next</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1068"/>
+        <source>Change &amp;timeout</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1069"/>
+        <source>Move &amp;up</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1072"/>
+        <location filename="../mainwindow.cpp" line="1088"/>
+        <source>not set, will boot using list order</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1105"/>
+        <source>Set &amp;inactive</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1157"/>
         <source>Needs reboot</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="838"/>
+        <location filename="../mainwindow.cpp" line="1157"/>
         <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="891"/>
+        <location filename="../mainwindow.cpp" line="1212"/>
         <source>Click to select theme</source>
         <translation type="unfinished"/>
     </message>
@@ -359,7 +514,7 @@ OK to go ahead and install them?</source>
 <context>
     <name>QApplication</name>
     <message>
-        <location filename="main.cpp" line="42"/>
+        <location filename="../main.cpp" line="50"/>
         <source>Program for selecting common start-up choices</source>
         <translation type="unfinished"/>
     </message>
@@ -367,22 +522,22 @@ OK to go ahead and install them?</source>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="main.cpp" line="61"/>
+        <location filename="../main.cpp" line="70"/>
         <source>Error</source>
         <translation>Lỗi</translation>
     </message>
     <message>
-        <location filename="main.cpp" line="62"/>
+        <location filename="../main.cpp" line="71"/>
         <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="720"/>
+        <location filename="../mainwindow.cpp" line="943"/>
         <source>Select image to display in bootloader</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="901"/>
+        <location filename="../mainwindow.cpp" line="1222"/>
         <source>Select GRUB theme</source>
         <translation type="unfinished"/>
     </message>
